@@ -20,7 +20,7 @@ import Pyro4
 
 __all__=["URI", "Proxy", "Daemon", "callback", "batch", "async"]
 
-if sys.version_info>(3, 0):
+if sys.version_info>=(3, 0):
     basestring=str
 
 log=logging.getLogger("Pyro.core")
@@ -32,7 +32,7 @@ class URI(object):
     The uri format is like this: ``PYRO:objectid@location`` where location is one of:
 
     - ``hostname:port`` (tcp/ip socket on given port)
-    - ``./u:sockname`` (unix domain socket on localhost)
+    - ``./u:sockname`` (Unix domain socket on localhost)
 
     There is also a 'Magic format' for simple name resolution using Name server:
       ``PYRONAME:objectname[@location]``  (optional name server location, can also omit location port)
@@ -82,10 +82,12 @@ class URI(object):
 
     @staticmethod
     def isUnixsockLocation(location):
+        """determine if a location string is for a Unix domain socket"""
         return location.startswith("./u:")
 
     @property
     def location(self):
+        """property containing the location string, for instance ``"servername.you.com:5555"``"""
         if self.host:
             return "%s:%d" % (self.host, self.port)
         elif self.sockname:
@@ -94,6 +96,7 @@ class URI(object):
             return None
 
     def asString(self):
+        """the string representation of this object"""
         result=self.protocol+":"+self.object
         location=self.location
         if location:
@@ -101,7 +104,16 @@ class URI(object):
         return result
 
     def __str__(self):
+        string=self.asString()
+        if sys.version_info<(3,0) and type(string) is unicode:
+            return string.encode("ascii", "replace")
+        return string
+
+    def __unicode__(self):
         return self.asString()
+    
+    def __repr__(self):
+        return "<%s.%s at 0x%x, %s>" % (self.__class__.__module__, self.__class__.__name__, id(self), str(self))
 
     def __eq__(self, other):
         return (self.protocol, self.object, self.sockname, self.host, self.port) \
@@ -139,11 +151,23 @@ def _check_hmac():
 
 
 class Proxy(object):
-    """Pyro proxy for a remote object. Intercepts method calls and dispatches them to the remote object."""
+    """
+    Pyro proxy for a remote object. Intercepts method calls and dispatches them to the remote object.
+
+    .. automethod:: _pyroBind
+    .. automethod:: _pyroRelease
+    .. automethod:: _pyroReconnect
+    .. automethod:: _pyroBatch
+    .. automethod:: _pyroAsync
+    """
     _pyroSerializer=util.Serializer()
     __pyroAttributes=frozenset(["__getnewargs__", "__getinitargs__", "_pyroConnection", "_pyroUri", "_pyroOneway", "_pyroTimeout", "_pyroSeq"])
 
     def __init__(self, uri):
+        """
+        .. autoattribute:: _pyroOneway
+        .. autoattribute:: _pyroTimeout
+        """
         _check_hmac()  # check if hmac secret key is set
         if isinstance(uri, basestring):
             uri=URI(uri)
@@ -166,8 +190,10 @@ class Proxy(object):
             raise AttributeError(name)
         return _RemoteMethod(self._pyroInvoke, name)
 
-    def __str__(self):
-        return "<Pyro Proxy for "+str(self._pyroUri)+">"
+    def __repr__(self):
+        connected="connected" if self._pyroConnection else "not connected"
+        return "<%s.%s at 0x%x, %s, for %s>" % (self.__class__.__module__, self.__class__.__name__,
+            id(self), connected, self._pyroUri)
 
     def __unicode__(self):
         return str(self)
@@ -230,6 +256,7 @@ class Proxy(object):
             data=MessageFactory.createMessage(MessageFactory.MSG_INVOKE, data, flags, self._pyroSeq)
             try:
                 self._pyroConnection.send(data)
+                del data  # invite GC to collect the object, don't wait for out-of-scope
                 if flags & MessageFactory.FLAGS_ONEWAY:
                     return None    # oneway call, no response data
                 else:
@@ -262,13 +289,13 @@ class Proxy(object):
         """Connects this proxy to the remote Pyro daemon. Does connection handshake."""
         from Pyro4.naming import resolve  # don't import this globally because of cyclic dependancy
         uri=resolve(self._pyroUri)
-        # socket connection (normal or unix domain socket)
+        # socket connection (normal or Unix domain socket)
         conn=None
         log.debug("connecting to %s", uri)
         connect_location=uri.sockname if uri.sockname else (uri.host, uri.port)
         try:
             with self.__pyroLock:
-                sock=socketutil.createSocket(connect=connect_location, timeout=self.__pyroTimeout)
+                sock=socketutil.createSocket(connect=connect_location, reuseaddr=Pyro4.config.SOCK_REUSE, timeout=self.__pyroTimeout)
                 conn=socketutil.SocketConnection(sock, uri.object)
                 # Do handshake. For now, no need to send anything.
                 msgType, flags, seq, data = MessageFactory.getMessage(conn, None)
@@ -306,6 +333,7 @@ class Proxy(object):
                 raise errors.ProtocolError(err)
 
     def _pyroReconnect(self, tries=100000000):
+        """(re)connect the proxy to the daemon containing the pyro object which the proxy is for"""
         self._pyroRelease()
         while tries:
             try:
@@ -320,9 +348,11 @@ class Proxy(object):
         raise errors.ConnectionClosedError(msg)
 
     def _pyroBatch(self):
+        """returns a helper class that lets you create batched method calls on the proxy"""
         return _BatchProxyAdapter(self)
 
     def _pyroAsync(self):
+        """returns a helper class that lets you do asynchronous method calls on the proxy"""
         return _AsyncProxyAdapter(self)
 
     def _pyroInvokeBatch(self, calls, oneway=False):
@@ -430,19 +460,27 @@ class _AsyncRemoteMethod(object):
 
 
 class _AsyncResult(object):
+    """
+    The result object for asynchronous calls.
+    """
     def __init__(self):
         self.__ready=threadutil.Event()
         self.callchain=[]
         self.valueLock=threadutil.Lock()
-    def ready(self, timeout=None):
-        if timeout is None:
+    def wait(self, timeout=None):
+        """
+        Wait for the result to become available, with optional timeout (in seconds).
+        Returns True if the result is ready, or False if it still isn't ready.
+        """
+        result=self.__ready.wait(timeout)
+        if result is None:
+            # older pythons return None from wait()
             return self.__ready.isSet()
-        else:
-            self.__ready.wait(timeout)
-            if self.__ready.isSet():
-                return True
-            else:
-                raise Pyro4.errors.AsyncResultTimeout("async result didn't arrive in time")
+        return result
+    @property
+    def ready(self):
+        """Boolean that contains the readiness of the async result"""
+        return self.__ready.isSet()
     def get_value(self):
         self.__ready.wait()
         if isinstance(self.__value, _ExceptionWrapper):
@@ -456,8 +494,12 @@ class _AsyncResult(object):
                 self.__value=call(self.__value, **kwargs)
             self.callchain=[]
             self.__ready.set()
-    value=property(get_value, set_value)
+    value=property(get_value, set_value, None, "The result value of the call. Reading it will block if not available yet.")
     def then(self, call, **kwargs):
+        """
+        Add a callback to the call chain, to be invoked when the results become available.
+        Optional keyword arguments in kwargs.
+        """
         if self.__ready.isSet():
             # value is already known, we need to process it immediately (can't use the callchain anymore)
             self.__value=call(self.__value, **kwargs)
@@ -573,6 +615,7 @@ def pyroObjectSerializer(self):
     """reduce function that automatically replaces Pyro objects by a Proxy"""
     daemon=getattr(self,"_pyroDaemon",None)
     if daemon:
+        # only return a proxy if the object is a registered pyro object
         return Pyro4.core.Proxy, (daemon.uriFor(self),)
     else:
         return self.__reduce__()
@@ -687,7 +730,7 @@ class Daemon(object):
         return self.transportServer.events(eventsockets)
 
     def shutdown(self):
-        """Cleanly terminate a deamon that is running in the requestloop. It must be running
+        """Cleanly terminate a daemon that is running in the requestloop. It must be running
         in a different thread, or this method will deadlock."""
         log.debug("daemon shutting down")
         self.__mustshutdown.set()
@@ -724,6 +767,7 @@ class Daemon(object):
             msgType, flags, seq, data = MessageFactory.getMessage(conn, MessageFactory.MSG_INVOKE)
             objId, method, vargs, kwargs=self.serializer.deserialize(
                                            data, compressed=flags & MessageFactory.FLAGS_COMPRESSED)
+            del data  # invite GC to collect the object, don't wait for out-of-scope
             obj=self.objectsById.get(objId)
             if obj is not None:
                 if kwargs and sys.version_info<(2, 6, 5) and os.name!="java":
@@ -807,7 +851,7 @@ class Daemon(object):
         if hasattr(obj, "_pyroId"):
             raise errors.DaemonError("object already has a Pyro id")
         if objectId in self.objectsById:
-            raise errors.DaemonError("object already registered")
+            raise errors.DaemonError("object already registered with that id")
         # set some pyro attributes
         obj._pyroId=objectId
         obj._pyroDaemon=self
@@ -842,12 +886,11 @@ class Daemon(object):
             if objectOrId is not None:
                 del objectOrId._pyroId
                 del objectOrId._pyroDaemon
-                if Pyro4.config.AUTOPROXY:
-                    # remove the custom type serializer
-                    try:
-                        copyreg.pickle(type(objectOrId),defaultObjectSerializer)
-                    except TypeError:
-                        pass
+                # Don't remove the custom type serializer (copyreg.pickle) because there
+                # may be other registered objects of the same type still depending on it.
+                # Also, it would require an inefficient linear search through the registered
+                # objects map to scan for types. Finally, the copyreg module doesn't seem
+                # to be designed with cleanup in mind (it has no explicit unregister function)
 
     def uriFor(self, objectOrId=None):
         """
@@ -870,8 +913,9 @@ class Daemon(object):
             self.transportServer.close()
             self.transportServer=None
 
-    def __str__(self):
-        return "<Pyro Daemon on "+self.locationStr+">"
+    def __repr__(self):
+        return "<%s.%s at 0x%x, %s, %d objects>" % (self.__class__.__module__, self.__class__.__name__,
+            id(self), self.locationStr, len(self.objectsById))
 
     def __enter__(self):
         if not self.transportServer:
