@@ -12,7 +12,7 @@ from Pyro4.threadutil import RLock, Thread
 from Pyro4.errors import PyroError, NamingError
 import Pyro4
 
-__all__=["locateNS", "resolve"]
+__all__=["locateNS", "resolve", "startNS"]
 
 if sys.version_info>=(3, 0):
     basestring=str
@@ -147,7 +147,7 @@ class BroadcastServer(object):
             bcport=Pyro4.config.NS_BCPORT
         if bchost is None:
             bchost=Pyro4.config.NS_BCHOST
-        self.sock=Pyro4.socketutil.createBroadcastSocket((bchost, bcport), timeout=2.0)
+        self.sock=Pyro4.socketutil.createBroadcastSocket((bchost, bcport), reuseaddr=Pyro4.config.SOCK_REUSE, timeout=2.0)
         self._sockaddr=self.sock.getsockname()
         bchost=bchost or self._sockaddr[0]
         bcport=bcport or self._sockaddr[1]
@@ -212,7 +212,7 @@ def startNSloop(host=None, port=None, enableBroadcast=True, bchost=None, bcport=
     nsUri=daemon.uriFor(daemon.nameserver)
     bcserver=None
     if unixsocket:
-        hostip="unix domain socket"
+        hostip="Unix domain socket"
     else:
         hostip=daemon.sock.getsockname()[0]
         if hostip.startswith("127."):
@@ -268,7 +268,7 @@ def locateNS(host=None, port=None):
         if not port:
             port=Pyro4.config.NS_BCPORT
         log.debug("broadcast locate")
-        sock=Pyro4.socketutil.createBroadcastSocket(timeout=0.7)
+        sock=Pyro4.socketutil.createBroadcastSocket(reuseaddr=Pyro4.config.SOCK_REUSE, timeout=0.7)
         for _ in range(3):
             try:
                 sock.sendto(BroadcastServer.REQUEST_NSURI, 0, ("<broadcast>", port))
@@ -326,7 +326,7 @@ def main(args):
     parser=OptionParser()
     parser.add_option("-n", "--host", dest="host", help="hostname to bind server on")
     parser.add_option("-p", "--port", dest="port", type="int", help="port to bind server on (0=random)")
-    parser.add_option("-u","--unixsocket", help="unix domain socket name to bind server on")
+    parser.add_option("-u","--unixsocket", help="Unix domain socket name to bind server on")
     parser.add_option("", "--bchost", dest="bchost", help="hostname to bind broadcast server on (default is \"\")")
     parser.add_option("", "--bcport", dest="bcport", type="int",
                       help="port to bind broadcast server on (0=random)")
