@@ -18,7 +18,7 @@ class MultiplexedSocketServerBase(object):
         log.info("starting multiplexed socketserver")
         self.sock=None
         bind_location=unixsocket if unixsocket else (host, port)
-        self.sock=socketutil.createSocket(bind=bind_location, timeout=Pyro4.config.COMMTIMEOUT, noinherit=True)
+        self.sock=socketutil.createSocket(bind=bind_location, reuseaddr=Pyro4.config.SOCK_REUSE, timeout=Pyro4.config.COMMTIMEOUT, noinherit=True)
         self.clients=[]
         self.daemon=daemon
         sockaddr=self.sock.getsockname()
@@ -32,6 +32,9 @@ class MultiplexedSocketServerBase(object):
             port=port or sockaddr[1]
             self.locationStr="%s:%d" % (host, port)
 
+    def __repr__(self):
+        return "<%s on %s, %d connections>" % (self.__class__.__name__, self.locationStr, len(self.clients))
+
     def __del__(self):
         if self.sock is not None:
             self.sock.close()
@@ -91,7 +94,7 @@ class MultiplexedSocketServerBase(object):
                 pass
             self.sock.close()
             if type(sockname) is str:
-                # it was a unix domain socket, remove it from the filesystem
+                # it was a Unix domain socket, remove it from the filesystem
                 if os.path.exists(sockname):
                     os.remove(sockname)
         self.sock=None
