@@ -2,7 +2,7 @@
 Tests for the package structure and import names.
 
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong.
-irmen@razorvine.net - http://www.razorvine.net/python/Pyro
+irmen@razorvine.net - http://www.razorvine.net/projects/Pyro
 """
 
 import unittest
@@ -22,6 +22,8 @@ class TestPackage(unittest.TestCase):
         self.assertEqual(Pyro4.core.Proxy, Pyro4.Proxy)
         self.assertEqual(Pyro4.core.URI, Pyro4.URI)
         self.assertEqual(Pyro4.core.callback, Pyro4.callback)
+        self.assertEqual(Pyro4.core.async, Pyro4.async)
+        self.assertEqual(Pyro4.core.batch, Pyro4.batch)
         self.assertEqual(Pyro4.naming.locateNS, Pyro4.locateNS)
         self.assertEqual(Pyro4.naming.resolve, Pyro4.resolve)
 
