@@ -2,13 +2,14 @@
 Tests for the utility functions.
 
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong.
-irmen@razorvine.net - http://www.razorvine.net/python/Pyro
+irmen@razorvine.net - http://www.razorvine.net/projects/Pyro
 """
 
 import unittest
 
-import sys, imp, os
+import sys, imp, os, platform
 import Pyro4.util
+from testsupport import *
 
 if not hasattr(imp,"reload"):
     imp.reload=reload   # python 2.5 doesn't have imp.reload
@@ -104,6 +105,31 @@ class TestUtils(unittest.TestCase):
             self.assertRaises(TypeError, Pyro4.util.getPyroTraceback, x)
             self.assertRaises(TypeError, Pyro4.util.formatTraceback, x)
 
+    def testExcepthook(self):
+        # simply test the excepthook by calling it the way Python would
+        try:
+            crash()
+            self.fail("must crash with ZeroDivisionError")
+        except ZeroDivisionError:
+            pyro_tb=Pyro4.util.formatTraceback()
+        try:
+            crash("stringvalue")
+            self.fail("must crash with TypeError")
+        except TypeError:
+            ex_type,ex_value,ex_tb=sys.exc_info()
+            ex_value._pyroTraceback=pyro_tb        # set the remote traceback info
+            oldstderr=sys.stderr
+            try:
+                sys.stderr=StringIO()
+                Pyro4.util.excepthook(ex_type, ex_value, ex_tb)
+                output=sys.stderr.getvalue()
+                self.assertTrue("Remote traceback" in output)
+                self.assertTrue("crash(\"stringvalue\")" in output)
+                self.assertTrue("TypeError:" in output)
+                self.assertTrue("ZeroDivisionError" in output)
+            finally:
+                sys.stderr=oldstderr
+
     def testConfig(self):
         def clearEnv():
             if "PYRO_HOST" in os.environ: del os.environ["PYRO_HOST"]
@@ -162,6 +188,19 @@ class TestUtils(unittest.TestCase):
         self.assertRaises(AttributeError,Pyro4.util.resolveDottedAttribute, obj,"a._p.q",True)    #private
         self.assertRaises(AttributeError,Pyro4.util.resolveDottedAttribute, obj,"a.__p.q",True)    #private
 
+    def testUnicodeKwargs(self):
+        # test the way the interpreter deals with unicode function kwargs
+        # those are supported by Python after 2.6.5, but not (all) by PyPy
+        # see https://bugs.pypy.org/issue751
+        def function(*args, **kwargs):
+            return args, kwargs
+        if sys.version_info>=(2,6,5):
+            processed_args=function(*(1,2,3), **{ unichr(65): 42 })
+            self.assertEqual( ((1,2,3), { unichr(65): 42}), processed_args)
+            if platform.python_implementation()!="PyPy":
+                processed_args=function(*(1,2,3), **{ unichr(0x20ac): 42 })
+                self.assertEqual( ((1,2,3), { unichr(0x20ac): 42}), processed_args)
+
 if __name__ == "__main__":
     #import sys;sys.argv = ['', 'Test.testName']
     unittest.main()
